<?php

namespace Test\Test\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Test\Test\Http\Requests\EventRequest;
use Test\Test\Interfaces\EventRepositoryInterface;
use Test\Test\Models\Event;

/**
 * Admin API controller class.
 */
class EventAdminController extends BaseController
{
    /**
     * Initialize event controller.
     *
     * @param type EventRepositoryInterface $event
     *
     * @return type
     */
    public function __construct(EventRepositoryInterface $event)
    {
        $this->repository = $event;
        parent::__construct();
    }

    /**
     * Display a list of event.
     *
     * @return json
     */
    public function index(EventRequest $request)
    {
        $events  = $this->repository
            ->setPresenter('\\Test\\Test\\Repositories\\Presenter\\EventListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $events['code'] = 2000;
        return response()->json($events) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display event.
     *
     * @param Request $request
     * @param Model   Event
     *
     * @return Json
     */
    public function show(EventRequest $request, Event $event)
    {
        $event         = $event->presenter();
        $event['code'] = 2001;
        return response()->json($event)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new event.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(EventRequest $request, Event $event)
    {
        $event         = $event->presenter();
        $event['code'] = 2002;
        return response()->json($event)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new event.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(EventRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $event          = $this->repository->create($attributes);
            $event          = $event->presenter();
            $event['code']  = 2004;

            return response()->json($event)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show event for editing.
     *
     * @param Request $request
     * @param Model   $event
     *
     * @return json
     */
    public function edit(EventRequest $request, Event $event)
    {
        $event         = $event->presenter();
        $event['code'] = 2003;
        return response()-> json($event)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the event.
     *
     * @param Request $request
     * @param Model   $event
     *
     * @return json
     */
    public function update(EventRequest $request, Event $event)
    {
        try {

            $attributes = $request->all();

            $event->update($attributes);
            $event         = $event->presenter();
            $event['code'] = 2005;

            return response()->json($event)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the event.
     *
     * @param Request $request
     * @param Model   $event
     *
     * @return json
     */
    public function destroy(EventRequest $request, Event $event)
    {
        try {
            $t = $event->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('test::event.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
