<?php

namespace Test\Test\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Test\Test\Interfaces\EventRepositoryInterface;
use Test\Test\Repositories\Presenter\EventItemTransformer;

/**
 * Pubic API controller class.
 */
class EventPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Test\Event\Interfaces\EventRepositoryInterface $event
     *
     * @return type
     */
    public function __construct(EventRepositoryInterface $event)
    {
        $this->repository = $event;
        parent::__construct();
    }

    /**
     * Show event's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $events = $this->repository
            ->setPresenter('\\Test\\Test\\Repositories\\Presenter\\EventListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $events['code'] = 2000;
        return response()->json($events)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show event.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $event = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($event)) {
            $event         = $this->itemPresenter($module, new EventItemTransformer);
            $event['code'] = 2001;
            return response()->json($event)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
