<?php

namespace Test\Test\Http\Controllers;

use App\Http\Controllers\ClientController as BaseController;
use Form;
use Test\Test\Http\Requests\EventRequest;
use Test\Test\Interfaces\EventRepositoryInterface;
use Test\Test\Models\Event;

class EventClientController extends BaseController
{
    /**
     * Initialize event controller.
     *
     * @param type EventRepositoryInterface $event
     *
     * @return type
     */
    public function __construct(EventRepositoryInterface $event)
    {
        $this->repository = $event;
        $this->repository
            ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
            ->pushCriteria(new \Test\Test\Repositories\Criteria\EventCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(EventRequest $request)
    {
        $events = $this->repository->scopeQuery(function ($query) {
            return $query->orderBy('id', 'DESC');
        })->paginate();

        $this->theme->prependTitle(trans('test::event.names'));
        return $this->theme->of('test::public.event.index', compact('events'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Event $event
     *
     * @return Response
     */
    public function show(EventRequest $request, Event $event)
    {
        Form::populate($event);

        $this->theme->prependTitle(trans('test::event.names'));
        return $this->theme->of('test::public.event.show', compact('event'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EventRequest $request)
    {
        $event = $this->repository->newInstance([]);
        Form::populate($event);

        $this->theme->prependTitle(trans('app.create') . ' ' . trans('test::event.names'));
        return $this->theme->of('test::public.event.create', compact('event'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EventRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $event             = $this->repository->create($attributes);

            return redirect(trans_url('event'))
                ->with('message', trans('messages.success.created', ['Module' => trans('test::event.name')]))
                ->with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Event $event
     *
     * @return Response
     */
    public function edit(EventRequest $request, Event $event)
    {
        Form::populate($event);
        $this->theme->prependTitle(trans('app.edit') . ' ' . trans('test::event.names'));

        return $this->theme->of('test::public.event.edit', compact('event'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Event $event
     *
     * @return Response
     */
    public function update(EventRequest $request, Event $event)
    {
        try {
            $this->repository->update($request->all(), $event->getRouteKey());

            return redirect(trans_url('event'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('test::event.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(EventRequest $request, Event $event)
    {

        try {

            $t = $event->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('test::event.name')]),
                'code'     => 202,
                'redirect' => trans_url('/event'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/event/'.$event->getRouteKey()),
            ], 400);
        }
    }
}
