<?php

namespace Test\Test\Http\Controllers;
use Litepie\Test\Http\Requests\EventRequest;
use Litepie\Test\Models\Event;

trait EventWorkflow {
	
    /**
     * Workflow controller function for event.
     *
     * @param Model   $event
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(EventRequest $request, Event $event, $step)
    {

        try {

            $event->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('test::event.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/event/event/' . $event->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/event/event/' . $event->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for event.
     *
     * @param Model   $event
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Event $event, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $event->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('test::event.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.event.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.event.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.event.message', $data)->render();

        }

    }
}