<?php

namespace Test\Test\Policies;

use Litepie\User\Contracts\UserPolicy;
use Test\Test\Models\Event;

class EventPolicy
{

    /**
     * Determine if the given user can view the event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function view(UserPolicy $user, Event $event)
    {
        if ($user->canDo('test.event.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $event->user_id;
    }

    /**
     * Determine if the given user can create a event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('test.event.create');
    }

    /**
     * Determine if the given user can update the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function update(UserPolicy $user, Event $event)
    {
        if ($user->canDo('test.event.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $event->user_id;
    }

    /**
     * Determine if the given user can delete the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Event $event)
    {
        if ($user->canDo('test.event.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $event->user_id;
    }

    /**
     * Determine if the given user can verify the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Event $event)
    {
        if ($user->canDo('test.event.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('test.event.verify') 
        && $user->is('manager')
        && $event->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Event $event)
    {
        if ($user->canDo('test.event.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
