<?php

namespace Test\Test\Providers;

use Illuminate\Support\ServiceProvider;

class TestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'test');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'test');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('test', function ($app) {
            return $this->app->make('Test\Test\Test');
        });

                // Bind Event to repository
        $this->app->bind(
            'Test\Test\Interfaces\EventRepositoryInterface',
            \Test\Test\Repositories\Eloquent\EventRepository::class
        );

        $this->app->register(\Test\Test\Providers\AuthServiceProvider::class);
                $this->app->register(\Test\Test\Providers\EventServiceProvider::class);
        
        $this->app->register(\Test\Test\Providers\RouteServiceProvider::class);
                $this->app->register(\Test\Test\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['test'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('test/test.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/test')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/test')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
