<?php

namespace Test\Test\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Test\Test\Models\Event;

class EventAction
{
    /**
     * Perform the complete action.
     *
     * @param Event $event
     *
     * @return Event
     */
    public function complete(Event $event)
    {
        try {
            $event->status = 'complete';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Event $event
     *
     * @return Event
     */public function verify(Event $event)
    {
        try {
            $event->status = 'verify';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Event $event
     *
     * @return Event
     */public function approve(Event $event)
    {
        try {
            $event->status = 'approve';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Event $event
     *
     * @return Event
     */public function publish(Event $event)
    {
        try {
            $event->status = 'publish';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Event $event
     *
     * @return Event
     */
    public function archive(Event $event)
    {
        try {
            $event->status = 'archive';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Event $event
     *
     * @return Event
     */
    public function unpublish(Event $event)
    {
        try {
            $event->status = 'unpublish';
            return $event->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
