<?php

namespace Test\Test\Workflow;

use Test\Test\Models\Event;
use Validator;

class EventValidator
{

    /**
     * Determine if the given event is valid for complete status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function complete(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given event is valid for verify status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function verify(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given event is valid for approve status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function approve(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given event is valid for publish status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function publish(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given event is valid for archive status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function archive(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given event is valid for unpublish status.
     *
     * @param Event $event
     *
     * @return bool / Validator
     */
    public function unpublish(Event $event)
    {
        return Validator::make($event->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
